==> DeCiDa-1.1.3.tar.gz: DeCiDa-1.1.3/setup.py <==
from distutils.core import setup
import os.path

DECIDA_HOME = os.path.expanduser("~/.DeCiDa")

setup(
    name='DeCiDa',
    version='1.1.3',
    author='Richard Booth',
    author_email='rvhbooth@gmail.com',
    packages=['decida', 'decida.test'],
    requires=['future', 'six', 'numpy', 'matplotlib'],
    package_data={
        "decida": ["dataview_help/*", "twin_help/*", "plotter_help/*"],
        "decida.test": [
            "data/*.inc", "data/*.txt", "data/*.sp",
            "data/*.csv", "data/*.net", "data/*.ckt",
            "data/*.report", "data/*.col", "data/*.data",
            "data/LTspice/binary/*.raw",
            "data/LTspice/ascii/*.raw",
            "data/NGspice/binary/*.raw",
            "data/NGspice/binary/*.ckt",
            "data/hspice/binary/*.tr0",
            "data/hspice/binary/*.ac0",
            "data/hspice/binary/*.ckt",
            "data/hspice/ascii/*.tr0",
            "data/hspice/ascii/*.ac0",
            "data/hspice/ascii/*.ckt",
            "data/sspice/ascii/*.raw",
            "data/sspice/binary/*.raw"
        ]
    },
    scripts=[
        'bin/calc',
        'bin/dataview',
        'bin/gifimg',
        'bin/ngsp',
        'bin/op',
        'bin/pll_phase_noise',
        'bin/pllss',
        'bin/plotter',
        'bin/simvision_csv2col',
        'bin/twin',
    ],
    data_files=[
        (DECIDA_HOME + '/dot', [
               'etc/dot/.cdsinit',
               'etc/dot/.oceanrc',
               'etc/dot/.pythonrc.py',
           ]
        ),
        (DECIDA_HOME + '/lib', [
               'etc/lib/README',
           ]
        ),
        (DECIDA_HOME + '/projects/bird', [
               'etc/projects/bird/README',
           ]
        ),
        (DECIDA_HOME + '/projects/bird/scratch', [
               'etc/projects/bird/scratch/README',
           ]
        ),
        (DECIDA_HOME + '/projects/trane', [
               'etc/projects/trane/README',
           ]
        ),
        (DECIDA_HOME + '/projects/trane/scratch', [
               'etc/projects/trane/scratch/README',
           ]
        ),
        (DECIDA_HOME + '/stdcell/ptm_130nm', [
               'etc/stdcell/ptm_130nm/README',
               'etc/stdcell/ptm_130nm/LICENSE',
               'etc/stdcell/ptm_130nm/NangateOpenCellLibrary.v',
           ]
        ),
        (DECIDA_HOME + '/stdcell/ptm_45nm', [
               'etc/stdcell/ptm_45nm/README',
               'etc/stdcell/ptm_45nm/LICENSE',
               'etc/stdcell/ptm_45nm/NangateOpenCellLibrary.v',
           ]
        ),
        (DECIDA_HOME + '/bin', [
               'etc/wrappers/run_hspice',
               'etc/wrappers/run_ngspice',
               'etc/wrappers/run_spectre',
               'etc/wrappers/run_sspice',
           ]
        ),
        (DECIDA_HOME + '/models', [
               'etc/models/ptm_130nm.lib',
               'etc/models/ptm_130nm.scs',
               'etc/models/ptm_130nm_mos.inc',
               'etc/models/ptm_130nm_mos.scs',
               'etc/models/ptm_45nm.lib',
               'etc/models/ptm_45nm.scs',
               'etc/models/ptm_45nm_mos.inc',
               'etc/models/ptm_45nm_mos.scs',
           ]
        ),
        (DECIDA_HOME + '/skill', [
               'etc/skill/RVBcomp.il',
               'etc/skill/RVBdcd_help.txt',
               'etc/skill/RVBdcdlines.il',
               'etc/skill/RVBmenu.il',
               'etc/skill/RVButil.il',
               'etc/skill/RVBvtb_help.txt',
               'etc/skill/RVBvtblines.il',
           ]
        ),
        (DECIDA_HOME + '/verilog', [
               'etc/verilog/Makefile',
               'etc/verilog/make.bird',
               'etc/verilog/make.trane',
               'etc/verilog/make_body',
               'etc/verilog/simvision_core.tcl',
           ]
        ),
        (DECIDA_HOME + '/cython', [
               'etc/cython/setup_data.py',
               'etc/cython/setup_xyplotx.py',
           ]
        ),
        (DECIDA_HOME + '/matlab', [
               'etc/matlab/Data.m',
               'etc/matlab/test_Data_read_ssv.m',
               'etc/matlab/data2.ssv',
               'etc/matlab/NOTES',
           ]
        ),
        (DECIDA_HOME + '/doc', [
               'doc/html/searchindex.js',
               'doc/html/objects.inv',
               'doc/html/Balloonhelp.html',
               'doc/html/BinarySearch.html',
               'doc/html/Calc.html',
               'doc/html/CanvasIdentify.html',
               'doc/html/Contourx.html',
               'doc/html/Data.html',
               'doc/html/DataViewm.html',
               'doc/html/DataViewm_data_removal.html',
               'doc/html/DataViewm_equationset.html',
               'doc/html/DataViewm_menus.html',
               'doc/html/DataViewm_mouse.html',
               'doc/html/DialogBase.html',
               'doc/html/EquationParser.html',
               'doc/html/Fitter.html',
               'doc/html/FormulaCalculator.html',
               'doc/html/FrameNotebook.html',
               'doc/html/GetEntryDialog.html',
               'doc/html/Histogramx.html',
               'doc/html/ItclObjectx.html',
               'doc/html/Itemizer.html',
               'doc/html/LevMar.html',
               'doc/html/LevMar_minpack.html',
               'doc/html/LevMar_mpfit.html',
               'doc/html/MessageDialog.html',
               'doc/html/NGspice.html',
               'doc/html/PLL.html',
               'doc/html/PLLphaseNoise.html',
               'doc/html/Parameter.html',
               'doc/html/Parameters.html',
               'doc/html/Pattern.html',
               'doc/html/PlotBasem.html',
               'doc/html/Plotterm.html',
               'doc/html/Report.html',
               'doc/html/SelectionDialog.html',
               'doc/html/SimulatorNetlist.html',
               'doc/html/SmithChartx.html',
               'doc/html/StatusDialog.html',
               'doc/html/Tckt.html',
               'doc/html/TextWindow.html',
               'doc/html/XYplotm.html',
               'doc/html/XYplotm_annotation.html',
               'doc/html/XYplotm_line_parameters.html',
               'doc/html/XYplotm_menus.html',
               'doc/html/XYplotm_mouse.html',
               'doc/html/baseconvert.html',
               'doc/html/decida.html',
               'doc/html/decida_basic.html',
               'doc/html/decida_cadence_setup.html',
               'doc/html/decida_classes.html',
               'doc/html/decida_install.html',
               'doc/html/decida_ngspice_setup.html',
               'doc/html/decida_other.html',
               'doc/html/decida_screen.html',
               'doc/html/decida_sspice_setup.html',
               'doc/html/entry_emacs_bindings.html',
               'doc/html/genindex.html',
               'doc/html/grep.html',
               'doc/html/index.html',
               'doc/html/interpolate.html',
               'doc/html/multiline.html',
               'doc/html/pattern_alignment.html',
               'doc/html/range_sample.html',
               'doc/html/readfile2list.html',
               'doc/html/search.html',
               'doc/html/spice_value.html',
               'doc/html/syscall.html',
               'doc/html/vtb.html',
               'doc/html/writelist2file.html',
               'doc/html/_images/Calc.jpg',
               'doc/html/_images/CanvasIdentify.jpg',
               'doc/html/_images/Contourx.jpg',
               'doc/html/_images/DataViewm.jpg',
               'doc/html/_images/FormulaCalculator.jpg',
               'doc/html/_images/FrameNotebook.jpg',
               'doc/html/_images/GetEntryDialog.jpg',
               'doc/html/_images/Histogramx.jpg',
               'doc/html/_images/MessageDialog.jpg',
               'doc/html/_images/NGspice.jpg',
               'doc/html/_images/PLL.jpg',
               'doc/html/_images/PLLphaseNoise.jpg',
               'doc/html/_images/Plotterm.jpg',
               'doc/html/_images/SelectionDialog.jpg',
               'doc/html/_images/SmithChartx.jpg',
               'doc/html/_images/TextWindow.jpg',
               'doc/html/_images/XYplotm.jpg',
               'doc/html/_images/surveycourse2vector.jpg',
               'doc/html/_static/Calc.jpg',
               'doc/html/_static/CanvasIdentify.jpg',
               'doc/html/_static/Contourx.jpg',
               'doc/html/_static/DataViewm.jpg',
               'doc/html/_static/FormulaCalculator.jpg',
               'doc/html/_static/FrameNotebook.jpg',
               'doc/html/_static/GetEntryDialog.jpg',
               'doc/html/_static/Histogramx.jpg',
               'doc/html/_static/MessageDialog.jpg',
               'doc/html/_static/NGspice.jpg',
               'doc/html/_static/PLL.jpg',
               'doc/html/_static/PLLphaseNoise.jpg',
               'doc/html/_static/Plotterm.jpg',
               'doc/html/_static/SelectionDialog.jpg',
               'doc/html/_static/Smithchartx.jpg',
               'doc/html/_static/TextWindow.jpg',
               'doc/html/_static/XYplotm.jpg',
               'doc/html/_static/ajax-loader.gif',
               'doc/html/_static/basic.css',
               'doc/html/_static/classic.css',
               'doc/html/_static/comment-bright.png',
               'doc/html/_static/comment-close.png',
               'doc/html/_static/comment.png',
               'doc/html/_static/default.css',
               'doc/html/_static/doctools.js',
               'doc/html/_static/down-pressed.png',
               'doc/html/_static/down.png',
               'doc/html/_static/file.png',
               'doc/html/_static/jquery-3.1.0.js',
               'doc/html/_static/jquery.js',
               'doc/html/_static/minus.png',
               'doc/html/_static/plus.png',
               'doc/html/_static/pygments.css',
               'doc/html/_static/searchtools.js',
               'doc/html/_static/sidebar.js',
               'doc/html/_static/surveycourse2vector.jpg',
               'doc/html/_static/underscore-1.3.1.js',
               'doc/html/_static/underscore.js',
               'doc/html/_static/up-pressed.png',
               'doc/html/_static/up.png',
               'doc/html/_static/websupport.js',
               'doc/html/_sources/Balloonhelp.rst.txt',
               'doc/html/_sources/BinarySearch.rst.txt',
               'doc/html/_sources/Calc.rst.txt',
               'doc/html/_sources/CanvasIdentify.rst.txt',
               'doc/html/_sources/Contourx.rst.txt',
               'doc/html/_sources/Data.rst.txt',
               'doc/html/_sources/DataViewm.rst.txt',
               'doc/html/_sources/DataViewm_data_removal.rst.txt',
               'doc/html/_sources/DataViewm_equationset.rst.txt',
               'doc/html/_sources/DataViewm_menus.rst.txt',
               'doc/html/_sources/DataViewm_mouse.rst.txt',
               'doc/html/_sources/DialogBase.rst.txt',
               'doc/html/_sources/EquationParser.rst.txt',
               'doc/html/_sources/Fitter.rst.txt',
               'doc/html/_sources/FormulaCalculator.rst.txt',
               'doc/html/_sources/FrameNotebook.rst.txt',
               'doc/html/_sources/GetEntryDialog.rst.txt',
               'doc/html/_sources/Histogramx.rst.txt',
               'doc/html/_sources/ItclObjectx.rst.txt',
               'doc/html/_sources/Itemizer.rst.txt',
               'doc/html/_sources/LevMar.rst.txt',
               'doc/html/_sources/LevMar_minpack.rst.txt',
               'doc/html/_sources/LevMar_mpfit.rst.txt',
               'doc/html/_sources/MessageDialog.rst.txt',
               'doc/html/_sources/NGspice.rst.txt',
               'doc/html/_sources/PLL.rst.txt',
               'doc/html/_sources/PLLphaseNoise.rst.txt',
               'doc/html/_sources/Parameter.rst.txt',
               'doc/html/_sources/Parameters.rst.txt',
               'doc/html/_sources/Pattern.rst.txt',
               'doc/html/_sources/PlotBasem.rst.txt',
               'doc/html/_sources/Plotterm.rst.txt',
               'doc/html/_sources/Report.rst.txt',
               'doc/html/_sources/SelectionDialog.rst.txt',
               'doc/html/_sources/SimulatorNetlist.rst.txt',
               'doc/html/_sources/SmithChartx.rst.txt',
               'doc/html/_sources/StatusDialog.rst.txt',
               'doc/html/_sources/Tckt.rst.txt',
               'doc/html/_sources/TextWindow.rst.txt',
               'doc/html/_sources/XYplotm.rst.txt',
               'doc/html/_sources/XYplotm_annotation.rst.txt',
               'doc/html/_sources/XYplotm_line_parameters.rst.txt',
               'doc/html/_sources/XYplotm_menus.rst.txt',
               'doc/html/_sources/XYplotm_mouse.rst.txt',
               'doc/html/_sources/baseconvert.rst.txt',
               'doc/html/_sources/decida.rst.txt',
               'doc/html/_sources/decida_basic.rst.txt',
               'doc/html/_sources/decida_cadence_setup.rst.txt',
               'doc/html/_sources/decida_classes.rst.txt',
               'doc/html/_sources/decida_install.rst.txt',
               'doc/html/_sources/decida_ngspice_setup.rst.txt',
               'doc/html/_sources/decida_other.rst.txt',
               'doc/html/_sources/decida_screen.rst.txt',
               'doc/html/_sources/decida_sspice_setup.rst.txt',
               'doc/html/_sources/entry_emacs_bindings.rst.txt',
               'doc/html/_sources/grep.rst.txt',
               'doc/html/_sources/index.rst.txt',
               'doc/html/_sources/interpolate.rst.txt',
               'doc/html/_sources/multiline.rst.txt',
               'doc/html/_sources/pattern_alignment.rst.txt',
               'doc/html/_sources/range_sample.rst.txt',
               'doc/html/_sources/readfile2list.rst.txt',
               'doc/html/_sources/spice_value.rst.txt',
               'doc/html/_sources/syscall.rst.txt',
               'doc/html/_sources/vtb.rst.txt',
               'doc/html/_sources/writelist2file.rst.txt',
           ]
        ),
    ],
    url='http://decida.org',
    license='LICENSE.txt',
    description='Device and Circuit Data Analysis',
    long_description=open('README.txt').read(),
    platforms=["Linux", "MacOS", "CygWin", "Windows"],
    classifiers = [
            'License :: OSI Approved :: BSD License',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3',
            'Topic :: Multimedia :: Graphics',
            'Topic :: Scientific/Engineering',
            'Topic :: Scientific/Engineering :: Electronic Design Automation (EDA)',
            'Topic :: Scientific/Engineering :: Visualization',
    ]
)

==> DeCiDa-1.1.4.tar.gz: DeCiDa-1.1.4/setup.py <==
from setuptools import setup
import os.path

DECIDA_HOME = os.path.expanduser("~/.DeCiDa")

setup(
    name='DeCiDa',
    version='1.1.4',
    author='Richard Booth',
    author_email='rvhbooth@gmail.com',
    packages=['decida', 'decida.test'],
    ### install_requires=['future', 'six', 'numpy', 'matplotlib'],
    zip_safe=False,
    package_data={
        "decida": ["dataview_help/*", "twin_help/*", "plotter_help/*"],
        "decida.test": [
            "data/*.inc", "data/*.txt", "data/*.sp",
            "data/*.csv", "data/*.net", "data/*.ckt",
            "data/*.report", "data/*.col", "data/*.data",
            "data/LTspice/binary/*.raw",
            "data/LTspice/ascii/*.raw",
            "data/NGspice/binary/*.raw",
            "data/NGspice/binary/*.ckt",
            "data/hspice/binary/*.tr0",
            "data/hspice/binary/*.ac0",
            "data/hspice/binary/*.ckt",
            "data/hspice/ascii/*.tr0",
            "data/hspice/ascii/*.ac0",
            "data/hspice/ascii/*.ckt",
            "data/sspice/ascii/*.raw",
            "data/sspice/binary/*.raw"
        ]
    },
    scripts=[
        'bin/calc',
        'bin/dataview',
        'bin/gifimg',
        'bin/ngsp',
        'bin/op',
        'bin/pll_phase_noise',
        'bin/pllss',
        'bin/plotter',
        'bin/simvision_csv2col',
        'bin/twin',
    ],
    data_files=[
        (DECIDA_HOME + '/dot', [
               'etc/dot/.cdsinit',
               'etc/dot/.oceanrc',
               'etc/dot/.pythonrc.py',
           ]
        ),
        (DECIDA_HOME + '/lib', [
               'etc/lib/README',
           ]
        ),
        (DECIDA_HOME + '/projects/bird', [
               'etc/projects/bird/README',
           ]
        ),
        (DECIDA_HOME + '/projects/bird/scratch', [
               'etc/projects/bird/scratch/README',
           ]
        ),
        (DECIDA_HOME + '/projects/trane', [
               'etc/projects/trane/README',
           ]
        ),
        (DECIDA_HOME + '/projects/trane/scratch', [
               'etc/projects/trane/scratch/README',
           ]
        ),
        (DECIDA_HOME + '/stdcell/ptm_130nm', [
               'etc/stdcell/ptm_130nm/README',
               'etc/stdcell/ptm_130nm/LICENSE',
               'etc/stdcell/ptm_130nm/NangateOpenCellLibrary.v',
           ]
        ),
        (DECIDA_HOME + '/stdcell/ptm_45nm', [
               'etc/stdcell/ptm_45nm/README',
               'etc/stdcell/ptm_45nm/LICENSE',
               'etc/stdcell/ptm_45nm/NangateOpenCellLibrary.v',
           ]
        ),
        (DECIDA_HOME + '/bin', [
               'etc/wrappers/run_hspice',
               'etc/wrappers/run_ngspice',
               'etc/wrappers/run_spectre',
               'etc/wrappers/run_sspice',
           ]
        ),
        (DECIDA_HOME + '/models', [
               'etc/models/ptm_130nm.lib',
               'etc/models/ptm_130nm.scs',
               'etc/models/ptm_130nm_mos.inc',
               'etc/models/ptm_130nm_mos.scs',
               'etc/models/ptm_45nm.lib',
               'etc/models/ptm_45nm.scs',
               'etc/models/ptm_45nm_mos.inc',
               'etc/models/ptm_45nm_mos.scs',
           ]
        ),
        (DECIDA_HOME + '/skill', [
               'etc/skill/RVBcomp.il',
               'etc/skill/RVBdcd_help.txt',
               'etc/skill/RVBdcdlines.il',
               'etc/skill/RVBmenu.il',
               'etc/skill/RVButil.il',
               'etc/skill/RVBvtb_help.txt',
               'etc/skill/RVBvtblines.il',
           ]
        ),
        (DECIDA_HOME + '/verilog', [
               'etc/verilog/Makefile',
               'etc/verilog/make.bird',
               'etc/verilog/make.trane',
               'etc/verilog/make_body',
               'etc/verilog/simvision_core.tcl',
           ]
        ),
        (DECIDA_HOME + '/cython', [
               'etc/cython/setup_data.py',
               'etc/cython/setup_xyplotx.py',
           ]
        ),
        (DECIDA_HOME + '/matlab', [
               'etc/matlab/Data.m',
               'etc/matlab/test_Data_read_ssv.m',
               'etc/matlab/data2.ssv',
               'etc/matlab/NOTES',
           ]
        ),
        (DECIDA_HOME + '/doc', [
               'doc/decida_html.tar.gz',
           ]
        ),
    ],
    url='http://decida.org',
    license='LICENSE.txt',
    description='Device and Circuit Data Analysis',
    long_description=open('README.txt').read(),
    platforms=["Linux", "MacOS", "CygWin", "Windows"],
    classifiers = [
            'License :: OSI Approved :: BSD License',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3',
            'Topic :: Multimedia :: Graphics',
            'Topic :: Scientific/Engineering',
            'Topic :: Scientific/Engineering :: Electronic Design Automation (EDA)',
            'Topic :: Scientific/Engineering :: Visualization',
    ]
)
